warn("dtadmin: Loading DefenseTurret 3rd party admin interface");

// DefenseTurret admin module
// ----------------------------------------------------------------------------------------
// This script (scripts/dtAdmin.cs) will get executed by the DefenseTurret core, 
// if it is found to exist. 
//
// Alternatively, this script may be bundled into any other script of an admin
// mod, to override some of DT's behaviour.
//
// This script is merely an example of how an admin package can override some of 
// DefenseTurret's  behaviour. One piece of behaviour isn't overridable: Tainted 
// clients WILL get disconnected, regardless. The events shown here, is a basic
// example simply of overriding DT events to take extra actions.
//
// In addition to these events, there are functions that may be invoked
// to control DT's behaviour, or get information about a client.
// There are also a series of $Host:: preference variables that control DT's 
// behaviour at startup.

// ==================================== ADMIN VARIABLES ===================================
// These variables may only be set in serverprefs.cs or other prefs file.
//
// $Host::DefenseTurret::Active 			-set to 1 to enable DT or 0 to disable
// $Host::DefenseTurret::Optional 			-set to 1 to make DT optional on a server, or 0 to require it in FFA/Tourney
// $Host::DefenseTurret::RequiredInTourney 	-set to 1 to require DT in Tourney mode, or 0 to be optional
// $Host::DefenseTurret::MaxWptHeight 		-sets the maximum allowable height of a waypoint.

// Read the notes below, for admin mods wishing to enable/disable DT using a menu option,
// or some other mechanism. The $Host:: variables cannot be modified at runtime with any 
// effect. You have to use the functions below.
//


// ============================ INFORMATION FUNCTIONS ===================================
// DefenseTurret::GetClientStatus(%client)
//      returns -3 if the client id is a bot
//      returns -2 if the client id does not exist, or DTServer is not active
//                 (This could typically happen when missions are cycling)
//		returns -1 for players that don't have DT
//		returns 0 for clients that are tainted
// 		returns 1 for clients that are pure
//		It is important to note that a player's DT status can only be determined
//  	after 10 seconds of the client joining, i.e. receiving a MsgMissionDropInfo


// ============================ BEHAVIOUR FUNCTIONS =====================================
// DefenseTurret::SetActive(bool)
//		enables, or disables DefenseTurret
//		bool=1, sets DT as optional, bool=0 sets DT as required.
//		All clients will be notified of the action.
// 		The setting will be remember in $Host::DefenseTurret::Active as a 
// 		serverPrefs.cs setting. Admin mods wishing to toggle DT active,
//		or inactive, should use this method, instead of the $Host:: variable
//      Activating DT will only occur after the next mission has loaded, if
// 		DT was deactivated.
//		Deactivation occurs immediately.

// DefenseTurret::SetOptional(bool)
//		Sets DT be optional for clients, or not.
//		bool=1, sets DT as optional, bool=0 sets DT as required.
// 		The setting will be remembered in $Host::DefenseTurret::Optional as a 
// 		serverPrefs.cs setting. Admin mods wishing to toggle DT optional,
//		or required, should use this method, instead of the $Host:: variable

// DefenseTurret:SetMaxWptHeight(metres) 
//		Set the maximum height allowed for waypoints above terrain level
//		before the waypoint is considered illegal
//		The setting will be remembered in $Host::DefenseTurret::MaxWptHeight
//		as a serverPrefs.cs setting. Admin mods wishing to adjust the maximum
//		waypoint height should use this method, instead of accessing the
//		$Host:: variable directly.


// ========================== OVERRIDE EXAMPLES =====================================
// The following functions may be overridden to change DT's handling of certain events
// The default set of functions should suffice for most

// ----------------------------------------------------------------------------------
// ClientTainted - called whenever a client is considered tainted.
// 30 seconds after this event, the client will get disconnected by the core.
// An admin mod, may for instance decide to implement a kick, or a 1 day ban here.
// ----------------------------------------------------------------------------------
function DefenseTurret::ClientTainted(%client) 
{	
	if (!isObject(%client) )
		return;
	echo("dtadmin: detected a tainted client :" @ stripChars( detag( getTaggedString( %client.name ) ), "\cp\co\c6\c7\c8\c9" ));		
	// display the custom message to client
	bottomprint( %client,"<font:verdana bold:14><color:ff0000>DefenseTurret Error\nYour client is tainted.\nPlease correct the problem. Refer DefenseTurret documentation.",30,3);
	messageclient(%client,'Msg',"~wfx/misc/downloading.wav");
	messageclient(%client,'Msg',"~wvoice/Training/Mission5/T5_06c.wav");

}	



// ----------------------------------------------------------------------------------
// ClientHasIncorrectVersion - called whenever a client joins but and is running DT
// but the client's software version doesn't meet the server's minimum
// version requirement
//
// The default code just spams the client a message to download the latest version
// ----------------------------------------------------------------------------------
function DefenseTurret::ClientHasIncorrectVersion(%client) 
{
		centerprint( %client,"<font:verdana bold:14><color:ff0000>Your version of DefenseTurret does not meet server requirements.\n DefenseTurret will NOT be activated. Please download the latest version from http://www.triben.de",10,3);
		messageclient(%client,'Msg',"~wfx/misc/downloading.wav");
		messageclient(%client,'Msg',"~wvoice/Training/Mission5/T5_06c.wav");
		warn("dtadmin: client has an incorrect version of DT.");
}	



// ----------------------------------------------------------------------------------
// ClientHasNoDT - called whenever a client joins but is not running DT
// This event, may for example, display an advertisement message to the
// client, indicating where to get hold of the DT client, or if so decided
// the client may be shown a message saying "DT is required on this server"
//
// Another idea might be to check if the server is running in Tournament mode.
// If tournament mode is active, for instance, DT might be required, whereas
// in pub mode, it might be set as optional. In this instance the serverpref
// variable $Host::DefenseTurret::RequiredInTourney is used as an example.
//
// Note that this event is only called when a client joins, or the mission cycles
// To determine whether a client is DT enabled, or not, in the middle of a game
// DefenseTurret::GetClientStatus has to be called.
// ----------------------------------------------------------------------------------
function DefenseTurret::ClientHasNoDT(%client) 
{
	if (!isObject(%client))
		return;		
	echo("dtadmin: Client " @ stripChars( detag( getTaggedString( %client.name ) ), "\cp\co\c6\c7\c8\c9" ) @ " does not have defenseturret installed.");

	if ($Host::TournamentMode && $Host::DefenseTurret::RequiredInTourney) 
	{
		echo("dtadmin: client does not have the DT client required for tourney mode");
		bottomprint( %client,"<font:verdana bold:14><color:ff0000>DefenseTurret REQUIRED in Tournament mode\nThis server REQUIRES DefenseTurret in TOURNAMENT mode.\nDownload from http://www.triben.de",15,3);
	} 
	else 	
	{
		if (DefenseTurret.optional) 
		{
			echo("dtadmin: send optional advertisement to client");
			bottomprint( %client,"<font:verdana bold:14><color:ff0000>DefenseTurret Optional\nThis server does NOT require DefenseTurret.\nDownload from http://www.triben.de",5,3);
		} 
		else 
		{
			echo("dtadmin: send DT REQUIRED message to client");
			bottomprint( %client,"<font:verdana bold:14><color:ff0000>DefenseTurret REQUIRED\nThis server REQUIRES DefenseTurret.\nDownload from http://www.triben.de",30,3);
			%client.setDisconnectReason("DefenseTurret is required on this server... Download it ! http://www.triben.de");
			%client.schedule(30000,"delete");
			%client.sex="";
		}
	}
}	


// This implements a simple admin menu for changing DT behaviour
package dtadminmenu {
	function DefaultGame::sendGameVoteMenu( %game, %client, %key )	
	{
		parent::sendGameVoteMenu( %game, %client, %key );
		// add ours after the rest
		%isAdmin = ( %client.isSuperAdmin );
		if (!%isAdmin) return;
		
		if (DefenseTurret.active) 
			messageClient( %client, 'MsgVoteItem', "", %key, 'DTDeactivate', "", 'DT>Deactivate' );
		else 
			messageClient( %client, 'MsgVoteItem', "", %key, 'DTActivate', "", 'DT>Activate' );
			
		if (DefenseTurret.optional) 	
			messageClient( %client, 'MsgVoteItem', "", %key, 'DTSetRequired', "", 'DT>Set FFA Required' );
		else
			messageClient( %client, 'MsgVoteItem', "", %key, 'DTSetOptional', "", 'DT>Set FFA Optional' );

		if ($Host::DefenseTurret::RequiredInTourney==1) 	
			messageClient( %client, 'MsgVoteItem', "", %key, 'DTSetTOptional', "", 'DT>Set Tourney Optional' );
		else
			messageClient( %client, 'MsgVoteItem', "", %key, 'DTSetTRequired', "", 'DT>Set Tourney Required' );		
	}	
	
	//override server voting handler to grab DT specific menu responses
	function serverCmdStartNewVote(%client, %typeName, %arg1, %arg2, %arg3, %arg4, %playerVote)
	{
		parent::serverCmdStartNewVote(%client, %typeName, %arg1, %arg2, %arg3, %arg4, %playerVote);
		%isAdmin = (%client.isSuperAdmin);
		if (!%isAdmin) return;
		error("DT admin " @ getTaggedString(%client.name) @ "changed dt mode to  " @ %typeName);
		switch$ ( %typeName ) 
		{
			case "DTDeactivate" 	: 
				DefenseTurret::SetActive(0);
			case "DTActivate"  		: 
				DefenseTurret::SetActive(1);
			case "DTSetOptional"	: 
				DefenseTurret::SetOptional(1);
			case "DTSetRequired"	: 
				DefenseTurret::SetOptional(0);
			case "DTSetTOptional"	: 
				$Host::DefenseTurret::RequiredInTourney=0;
				messageAll('Msg', 'DefenseTurret clients are now optional in Tournament mode.');
				messageAll('Msg',"~wfx/misc/bounty_completed.wav");
			case "DTSetTRequired"	: 
				$Host::DefenseTurret::RequiredInTourney=1;
				messageAll('Msg', 'DefenseTurret clients are now REQUIRED in Tournament mode.');
				messageAll('Msg',"~wfx/misc/bounty_completed.wav");
				

		}
		
	}

};		


if (!isActivePackage(dtadminmenu)) {
	activatePackage(dtadminmenu);
}